# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/image/roi.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/image/roi.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.image import bindata_pb2 as biopb_dot_image_dot_bindata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62iopb/image/roi.proto\x12\x0b\x62iopb.image\x1a\x19\x62iopb/image/bindata.proto\"<\n\x05Point\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\x12\x11\n\x01z\x18\x03 \x01(\x02H\x00R\x01z\x88\x01\x01\x42\x04\n\x02_z\"q\n\tRectangle\x12-\n\x08top_left\x18\x01 \x01(\x0b\x32\x12.biopb.image.PointR\x07topLeft\x12\x35\n\x0c\x62ottom_right\x18\x02 \x01(\x0b\x32\x12.biopb.image.PointR\x0b\x62ottomRight\"m\n\x04Mask\x12\x34\n\trectangle\x18\x01 \x01(\x0b\x32\x16.biopb.image.RectangleR\trectangle\x12/\n\x08\x62in_data\x18\x02 \x01(\x0b\x32\x14.biopb.image.BinDataR\x07\x62inData\"a\n\x07\x45llipse\x12*\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x12.biopb.image.PointR\x06\x63\x65nter\x12*\n\x06radius\x18\x02 \x01(\x0b\x32\x12.biopb.image.PointR\x06radius\"5\n\x07Polygon\x12*\n\x06points\x18\x01 \x03(\x0b\x32\x12.biopb.image.PointR\x06points\"\xdc\x01\n\x04Mesh\x12(\n\x05verts\x18\x01 \x03(\x0b\x32\x12.biopb.image.PointR\x05verts\x12,\n\x05\x66\x61\x63\x65s\x18\x02 \x03(\x0b\x32\x16.biopb.image.Mesh.FaceR\x05\x66\x61\x63\x65s\x1a|\n\x04\x46\x61\x63\x65\x12\x0e\n\x02p1\x18\x01 \x01(\rR\x02p1\x12\x0e\n\x02p2\x18\x02 \x01(\rR\x02p2\x12\x0e\n\x02p3\x18\x03 \x01(\rR\x02p3\x12,\n\x07normals\x18\x04 \x03(\x0b\x32\x12.biopb.image.PointR\x07normals\x12\x16\n\x06values\x18\x05 \x03(\x02R\x06values\"\xa8\x02\n\x03ROI\x12*\n\x05point\x18\x01 \x01(\x0b\x32\x12.biopb.image.PointH\x00R\x05point\x12\x36\n\trectangle\x18\x02 \x01(\x0b\x32\x16.biopb.image.RectangleH\x00R\trectangle\x12\x30\n\x07\x65llipse\x18\x03 \x01(\x0b\x32\x14.biopb.image.EllipseH\x00R\x07\x65llipse\x12\x30\n\x07polygon\x18\x04 \x01(\x0b\x32\x14.biopb.image.PolygonH\x00R\x07polygon\x12\'\n\x04mesh\x18\x05 \x01(\x0b\x32\x11.biopb.image.MeshH\x00R\x04mesh\x12\'\n\x04mask\x18\x06 \x01(\x0b\x32\x11.biopb.image.MaskH\x00R\x04maskB\x07\n\x05shapeB\x0f\n\x0b\x62iopb.imageP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.image.roi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013biopb.imageP\001'
  _globals['_POINT']._serialized_start=65
  _globals['_POINT']._serialized_end=125
  _globals['_RECTANGLE']._serialized_start=127
  _globals['_RECTANGLE']._serialized_end=240
  _globals['_MASK']._serialized_start=242
  _globals['_MASK']._serialized_end=351
  _globals['_ELLIPSE']._serialized_start=353
  _globals['_ELLIPSE']._serialized_end=450
  _globals['_POLYGON']._serialized_start=452
  _globals['_POLYGON']._serialized_end=505
  _globals['_MESH']._serialized_start=508
  _globals['_MESH']._serialized_end=728
  _globals['_MESH_FACE']._serialized_start=604
  _globals['_MESH_FACE']._serialized_end=728
  _globals['_ROI']._serialized_start=731
  _globals['_ROI']._serialized_end=1027
# @@protoc_insertion_point(module_scope)
