# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/metadata.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import project_pb2 as biopb_dot_ome_dot_project__pb2
from biopb.ome import dataset_pb2 as biopb_dot_ome_dot_dataset__pb2
from biopb.ome import folder_pb2 as biopb_dot_ome_dot_folder__pb2
from biopb.ome import experiment_pb2 as biopb_dot_ome_dot_experiment__pb2
from biopb.ome import plate_pb2 as biopb_dot_ome_dot_plate__pb2
from biopb.ome import screen_pb2 as biopb_dot_ome_dot_screen__pb2
from biopb.ome import experimenter_pb2 as biopb_dot_ome_dot_experimenter__pb2
from biopb.ome import experimenter_group_pb2 as biopb_dot_ome_dot_experimenter__group__pb2
from biopb.ome import instrument_pb2 as biopb_dot_ome_dot_instrument__pb2
from biopb.ome import image_pb2 as biopb_dot_ome_dot_image__pb2
from biopb.ome import annotation_pb2 as biopb_dot_ome_dot_annotation__pb2
from biopb.ome import roi_pb2 as biopb_dot_ome_dot_roi__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62iopb/ome/metadata.proto\x12\tbiopb.ome\x1a\x17\x62iopb/ome/project.proto\x1a\x17\x62iopb/ome/dataset.proto\x1a\x16\x62iopb/ome/folder.proto\x1a\x1a\x62iopb/ome/experiment.proto\x1a\x15\x62iopb/ome/plate.proto\x1a\x16\x62iopb/ome/screen.proto\x1a\x1c\x62iopb/ome/experimenter.proto\x1a\"biopb/ome/experimenter_group.proto\x1a\x1a\x62iopb/ome/instrument.proto\x1a\x15\x62iopb/ome/image.proto\x1a\x1a\x62iopb/ome/annotation.proto\x1a\x13\x62iopb/ome/roi.proto\"\x8d\x0e\n\x08Metadata\x12=\n\x08projects\x18\x01 \x03(\x0b\x32!.biopb.ome.Metadata.ProjectsEntryR\x08projects\x12=\n\x08\x64\x61tasets\x18\x02 \x03(\x0b\x32!.biopb.ome.Metadata.DatasetsEntryR\x08\x64\x61tasets\x12:\n\x07\x66olders\x18\x03 \x03(\x0b\x32 .biopb.ome.Metadata.FoldersEntryR\x07\x66olders\x12\x46\n\x0b\x65xperiments\x18\x04 \x03(\x0b\x32$.biopb.ome.Metadata.ExperimentsEntryR\x0b\x65xperiments\x12\x37\n\x06plates\x18\x05 \x03(\x0b\x32\x1f.biopb.ome.Metadata.PlatesEntryR\x06plates\x12:\n\x07screens\x18\x06 \x03(\x0b\x32 .biopb.ome.Metadata.ScreensEntryR\x07screens\x12I\n\x0c\x65xperimenter\x18\x07 \x03(\x0b\x32%.biopb.ome.Metadata.ExperimenterEntryR\x0c\x65xperimenter\x12\\\n\x13\x65xperimenter_groups\x18\x08 \x03(\x0b\x32+.biopb.ome.Metadata.ExperimenterGroupsEntryR\x12\x65xperimenterGroups\x12\x46\n\x0binstruments\x18\t \x03(\x0b\x32$.biopb.ome.Metadata.InstrumentsEntryR\x0binstruments\x12\x37\n\x06images\x18\n \x03(\x0b\x32\x1f.biopb.ome.Metadata.ImagesEntryR\x06images\x12\x31\n\x04rois\x18\x0b \x03(\x0b\x32\x1d.biopb.ome.Metadata.RoisEntryR\x04rois\x12\x46\n\x0b\x61nnotations\x18\x0c \x03(\x0b\x32$.biopb.ome.Metadata.AnnotationsEntryR\x0b\x61nnotations\x1aO\n\rProjectsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x12.biopb.ome.ProjectR\x05value:\x02\x38\x01\x1aO\n\rDatasetsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x12.biopb.ome.DatasetR\x05value:\x02\x38\x01\x1aM\n\x0c\x46oldersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.biopb.ome.FolderR\x05value:\x02\x38\x01\x1aU\n\x10\x45xperimentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x15.biopb.ome.ExperimentR\x05value:\x02\x38\x01\x1aK\n\x0bPlatesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x10.biopb.ome.PlateR\x05value:\x02\x38\x01\x1aM\n\x0cScreensEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.biopb.ome.ScreenR\x05value:\x02\x38\x01\x1aX\n\x11\x45xperimenterEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.biopb.ome.ExperimenterR\x05value:\x02\x38\x01\x1a\x63\n\x17\x45xperimenterGroupsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32\x1c.biopb.ome.ExperimenterGroupR\x05value:\x02\x38\x01\x1aU\n\x10InstrumentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x15.biopb.ome.InstrumentR\x05value:\x02\x38\x01\x1aK\n\x0bImagesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x10.biopb.ome.ImageR\x05value:\x02\x38\x01\x1aG\n\tRoisEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x0e.biopb.ome.ROIR\x05value:\x02\x38\x01\x1aU\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x15.biopb.ome.AnnotationR\x05value:\x02\x38\x01\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_METADATA_PROJECTSENTRY']._loaded_options = None
  _globals['_METADATA_PROJECTSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_DATASETSENTRY']._loaded_options = None
  _globals['_METADATA_DATASETSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_FOLDERSENTRY']._loaded_options = None
  _globals['_METADATA_FOLDERSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_EXPERIMENTSENTRY']._loaded_options = None
  _globals['_METADATA_EXPERIMENTSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_PLATESENTRY']._loaded_options = None
  _globals['_METADATA_PLATESENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_SCREENSENTRY']._loaded_options = None
  _globals['_METADATA_SCREENSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_EXPERIMENTERENTRY']._loaded_options = None
  _globals['_METADATA_EXPERIMENTERENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_EXPERIMENTERGROUPSENTRY']._loaded_options = None
  _globals['_METADATA_EXPERIMENTERGROUPSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_INSTRUMENTSENTRY']._loaded_options = None
  _globals['_METADATA_INSTRUMENTSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_IMAGESENTRY']._loaded_options = None
  _globals['_METADATA_IMAGESENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_ROISENTRY']._loaded_options = None
  _globals['_METADATA_ROISENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA']._serialized_start=355
  _globals['_METADATA']._serialized_end=2160
  _globals['_METADATA_PROJECTSENTRY']._serialized_start=1163
  _globals['_METADATA_PROJECTSENTRY']._serialized_end=1242
  _globals['_METADATA_DATASETSENTRY']._serialized_start=1244
  _globals['_METADATA_DATASETSENTRY']._serialized_end=1323
  _globals['_METADATA_FOLDERSENTRY']._serialized_start=1325
  _globals['_METADATA_FOLDERSENTRY']._serialized_end=1402
  _globals['_METADATA_EXPERIMENTSENTRY']._serialized_start=1404
  _globals['_METADATA_EXPERIMENTSENTRY']._serialized_end=1489
  _globals['_METADATA_PLATESENTRY']._serialized_start=1491
  _globals['_METADATA_PLATESENTRY']._serialized_end=1566
  _globals['_METADATA_SCREENSENTRY']._serialized_start=1568
  _globals['_METADATA_SCREENSENTRY']._serialized_end=1645
  _globals['_METADATA_EXPERIMENTERENTRY']._serialized_start=1647
  _globals['_METADATA_EXPERIMENTERENTRY']._serialized_end=1735
  _globals['_METADATA_EXPERIMENTERGROUPSENTRY']._serialized_start=1737
  _globals['_METADATA_EXPERIMENTERGROUPSENTRY']._serialized_end=1836
  _globals['_METADATA_INSTRUMENTSENTRY']._serialized_start=1838
  _globals['_METADATA_INSTRUMENTSENTRY']._serialized_end=1923
  _globals['_METADATA_IMAGESENTRY']._serialized_start=1925
  _globals['_METADATA_IMAGESENTRY']._serialized_end=2000
  _globals['_METADATA_ROISENTRY']._serialized_start=2002
  _globals['_METADATA_ROISENTRY']._serialized_end=2073
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_start=2075
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_end=2160
# @@protoc_insertion_point(module_scope)
