# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/filter_set.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/filter_set.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/filter_set.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\x8a\x02\n\tFilterSet\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12\x30\n\x14\x65xcitation_filter_id\x18\x03 \x01(\tR\x12\x65xcitationFilterId\x12,\n\x12\x64ichroic_filter_id\x18\x04 \x01(\tR\x10\x64ichroicFilterId\x12,\n\x12\x65mission_filter_id\x18\x05 \x01(\tR\x10\x65missionFilterId\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIdsB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.filter_set_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_FILTERSET']._serialized_start=77
  _globals['_FILTERSET']._serialized_end=343
# @@protoc_insertion_point(module_scope)
