# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/roi.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/roi.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import bindata_pb2 as biopb_dot_ome_dot_bindata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x62iopb/ome/roi.proto\x12\tbiopb.ome\x1a\x17\x62iopb/ome/bindata.proto\"}\n\x0f\x41\x66\x66ineTransform\x12\x10\n\x03\x61\x30\x30\x18\x01 \x01(\x02R\x03\x61\x30\x30\x12\x10\n\x03\x61\x30\x31\x18\x02 \x01(\x02R\x03\x61\x30\x31\x12\x10\n\x03\x61\x30\x32\x18\x03 \x01(\x02R\x03\x61\x30\x32\x12\x10\n\x03\x61\x31\x30\x18\x04 \x01(\x02R\x03\x61\x31\x30\x12\x10\n\x03\x61\x31\x31\x18\x05 \x01(\x02R\x03\x61\x31\x31\x12\x10\n\x03\x61\x31\x32\x18\x06 \x01(\x02R\x03\x61\x31\x32\"S\n\tRectangle\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\x12\x14\n\x05width\x18\x03 \x01(\x02R\x05width\x12\x14\n\x05heigh\x18\x04 \x01(\x02R\x05heigh\"}\n\x04Mask\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\x12\x14\n\x05width\x18\x03 \x01(\x02R\x05width\x12\x14\n\x05heigh\x18\x04 \x01(\x02R\x05heigh\x12-\n\x08\x62in_data\x18\x05 \x01(\x0b\x32\x12.biopb.ome.BinDataR\x07\x62inData\"#\n\x05Point\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\"[\n\x07\x45llipse\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\x12\x19\n\x08radius_x\x18\x03 \x01(\x02R\x07radiusX\x12\x19\n\x08radius_y\x18\x04 \x01(\x02R\x07radiusY\"F\n\x04Line\x12\x0e\n\x02x1\x18\x01 \x01(\x02R\x02x1\x12\x0e\n\x02y1\x18\x02 \x01(\x02R\x02y1\x12\x0e\n\x02x2\x18\x03 \x01(\x02R\x02x2\x12\x0e\n\x02y2\x18\x04 \x01(\x02R\x02y2\"\xdf\x01\n\x08PolyLine\x12(\n\x06points\x18\x01 \x03(\x0b\x32\x10.biopb.ome.PointR\x06points\x12=\n\x0cmarker_start\x18\x02 \x01(\x0e\x32\x1a.biopb.ome.PolyLine.MarkerR\x0bmarkerStart\x12\x39\n\nmarker_end\x18\x03 \x01(\x0e\x32\x1a.biopb.ome.PolyLine.MarkerR\tmarkerEnd\"/\n\x06Marker\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05\x41RROW\x10\x01\x12\t\n\x05OTHER\x10\x02\"3\n\x07Polygon\x12(\n\x06points\x18\x01 \x03(\x0b\x32\x10.biopb.ome.PointR\x06points\"#\n\x05Label\x12\x0c\n\x01x\x18\x01 \x01(\x02R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x02R\x01y\"\x95\t\n\x05Shape\x12\x38\n\ttransform\x18\x02 \x01(\x0b\x32\x1a.biopb.ome.AffineTransformR\ttransform\x12\"\n\nfill_color\x18\x03 \x01(\rH\x01R\tfillColor\x88\x01\x01\x12\x36\n\tfill_rule\x18\x04 \x01(\x0e\x32\x19.biopb.ome.Shape.FillRuleR\x08\x66illRule\x12&\n\x0cstroke_color\x18\x05 \x01(\rH\x02R\x0bstrokeColor\x88\x01\x01\x12&\n\x0cstroke_width\x18\x06 \x01(\x02H\x03R\x0bstrokeWidth\x88\x01\x01\x12*\n\x11stroke_width_unit\x18\x07 \x01(\tR\x0fstrokeWidthUnit\x12(\n\x10stoke_dash_array\x18\x08 \x01(\tR\x0estokeDashArray\x12\x12\n\x04text\x18\t \x01(\tR\x04text\x12\x1f\n\x0b\x66ont_family\x18\n \x01(\tR\nfontFamily\x12 \n\tfont_size\x18\x0b \x01(\x02H\x04R\x08\x66ontSize\x88\x01\x01\x12$\n\x0e\x66ont_size_unit\x18\x0c \x01(\tR\x0c\x66ontSizeUnit\x12\x1d\n\nfont_style\x18\r \x01(\tR\tfontStyle\x12\x1b\n\x06locked\x18\x0e \x01(\x08H\x05R\x06locked\x88\x01\x01\x12\x18\n\x05the_z\x18\x0f \x01(\rH\x06R\x04theZ\x88\x01\x01\x12\x18\n\x05the_t\x18\x10 \x01(\rH\x07R\x04theT\x88\x01\x01\x12\x18\n\x05the_c\x18\x11 \x01(\rH\x08R\x04theC\x88\x01\x01\x12%\n\x0e\x61nnotation_ids\x18\x12 \x03(\tR\rannotationIds\x12\x34\n\trectangle\x18\x13 \x01(\x0b\x32\x14.biopb.ome.RectangleH\x00R\trectangle\x12%\n\x04mask\x18\x14 \x01(\x0b\x32\x0f.biopb.ome.MaskH\x00R\x04mask\x12(\n\x05point\x18\x15 \x01(\x0b\x32\x10.biopb.ome.PointH\x00R\x05point\x12.\n\x07\x65llipse\x18\x16 \x01(\x0b\x32\x12.biopb.ome.EllipseH\x00R\x07\x65llipse\x12%\n\x04line\x18\x17 \x01(\x0b\x32\x0f.biopb.ome.LineH\x00R\x04line\x12\x31\n\x08polyLine\x18\x18 \x01(\x0b\x32\x13.biopb.ome.PolyLineH\x00R\x08polyLine\x12.\n\x07polygon\x18\x19 \x01(\x0b\x32\x12.biopb.ome.PolygonH\x00R\x07polygon\x12(\n\x05label\x18\x1a \x01(\x0b\x32\x10.biopb.ome.LabelH\x00R\x05label\"@\n\x08\x46illRule\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x45VENODD\x10\x01\x12\x0b\n\x07NONZERO\x10\x02\x12\t\n\x05OTHER\x10\x03\x42\r\n\x0bshape_groupB\r\n\x0b_fill_colorB\x0f\n\r_stroke_colorB\x0f\n\r_stroke_widthB\x0c\n\n_font_sizeB\t\n\x07_lockedB\x08\n\x06_the_zB\x08\n\x06_the_tB\x08\n\x06_the_c\"\x8c\x01\n\x03ROI\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12(\n\x06shapes\x18\x04 \x03(\x0b\x32\x10.biopb.ome.ShapeR\x06shapes\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIdsB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.roi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_AFFINETRANSFORM']._serialized_start=59
  _globals['_AFFINETRANSFORM']._serialized_end=184
  _globals['_RECTANGLE']._serialized_start=186
  _globals['_RECTANGLE']._serialized_end=269
  _globals['_MASK']._serialized_start=271
  _globals['_MASK']._serialized_end=396
  _globals['_POINT']._serialized_start=398
  _globals['_POINT']._serialized_end=433
  _globals['_ELLIPSE']._serialized_start=435
  _globals['_ELLIPSE']._serialized_end=526
  _globals['_LINE']._serialized_start=528
  _globals['_LINE']._serialized_end=598
  _globals['_POLYLINE']._serialized_start=601
  _globals['_POLYLINE']._serialized_end=824
  _globals['_POLYLINE_MARKER']._serialized_start=777
  _globals['_POLYLINE_MARKER']._serialized_end=824
  _globals['_POLYGON']._serialized_start=826
  _globals['_POLYGON']._serialized_end=877
  _globals['_LABEL']._serialized_start=879
  _globals['_LABEL']._serialized_end=914
  _globals['_SHAPE']._serialized_start=917
  _globals['_SHAPE']._serialized_end=2090
  _globals['_SHAPE_FILLRULE']._serialized_start=1907
  _globals['_SHAPE_FILLRULE']._serialized_end=1971
  _globals['_ROI']._serialized_start=2093
  _globals['_ROI']._serialized_end=2233
# @@protoc_insertion_point(module_scope)
