# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/instrument.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/instrument.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import microscope_pb2 as biopb_dot_ome_dot_microscope__pb2
from biopb.ome import light_source_pb2 as biopb_dot_ome_dot_light__source__pb2
from biopb.ome import detector_pb2 as biopb_dot_ome_dot_detector__pb2
from biopb.ome import objective_pb2 as biopb_dot_ome_dot_objective__pb2
from biopb.ome import filter_set_pb2 as biopb_dot_ome_dot_filter__set__pb2
from biopb.ome import filter_pb2 as biopb_dot_ome_dot_filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/instrument.proto\x12\tbiopb.ome\x1a\x1a\x62iopb/ome/microscope.proto\x1a\x1c\x62iopb/ome/light_source.proto\x1a\x18\x62iopb/ome/detector.proto\x1a\x19\x62iopb/ome/objective.proto\x1a\x1a\x62iopb/ome/filter_set.proto\x1a\x16\x62iopb/ome/filter.proto\"\x85\x08\n\nInstrument\x12\x35\n\nmicroscope\x18\x01 \x01(\x0b\x32\x15.biopb.ome.MicroscopeR\nmicroscope\x12L\n\rlight_sources\x18\x02 \x03(\x0b\x32\'.biopb.ome.Instrument.LightSourcesEntryR\x0clightSources\x12\x42\n\tdetectors\x18\x03 \x03(\x0b\x32$.biopb.ome.Instrument.DetectorsEntryR\tdetectors\x12\x45\n\nobjectives\x18\x04 \x03(\x0b\x32%.biopb.ome.Instrument.ObjectivesEntryR\nobjectives\x12\x46\n\x0b\x66ilter_sets\x18\x05 \x03(\x0b\x32%.biopb.ome.Instrument.FilterSetsEntryR\nfilterSets\x12<\n\x07\x66ilters\x18\x06 \x03(\x0b\x32\".biopb.ome.Instrument.FiltersEntryR\x07\x66ilters\x12\x42\n\tdichroics\x18\x07 \x03(\x0b\x32$.biopb.ome.Instrument.DichroicsEntryR\tdichroics\x12%\n\x0e\x61nnotation_ids\x18\x08 \x03(\tR\rannotationIds\x1aW\n\x11LightSourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.biopb.ome.LightSourceR\x05value:\x02\x38\x01\x1aQ\n\x0e\x44\x65tectorsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x13.biopb.ome.DetectorR\x05value:\x02\x38\x01\x1aS\n\x0fObjectivesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x14.biopb.ome.ObjectiveR\x05value:\x02\x38\x01\x1aS\n\x0f\x46ilterSetsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x14.biopb.ome.FilterSetR\x05value:\x02\x38\x01\x1aM\n\x0c\x46iltersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.biopb.ome.FilterR\x05value:\x02\x38\x01\x1aQ\n\x0e\x44ichroicsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x13.biopb.ome.DichroicR\x05value:\x02\x38\x01\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.instrument_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_INSTRUMENT_LIGHTSOURCESENTRY']._loaded_options = None
  _globals['_INSTRUMENT_LIGHTSOURCESENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_DETECTORSENTRY']._loaded_options = None
  _globals['_INSTRUMENT_DETECTORSENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_OBJECTIVESENTRY']._loaded_options = None
  _globals['_INSTRUMENT_OBJECTIVESENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_FILTERSETSENTRY']._loaded_options = None
  _globals['_INSTRUMENT_FILTERSETSENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_FILTERSENTRY']._loaded_options = None
  _globals['_INSTRUMENT_FILTERSENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT_DICHROICSENTRY']._loaded_options = None
  _globals['_INSTRUMENT_DICHROICSENTRY']._serialized_options = b'8\001'
  _globals['_INSTRUMENT']._serialized_start=205
  _globals['_INSTRUMENT']._serialized_end=1234
  _globals['_INSTRUMENT_LIGHTSOURCESENTRY']._serialized_start=732
  _globals['_INSTRUMENT_LIGHTSOURCESENTRY']._serialized_end=819
  _globals['_INSTRUMENT_DETECTORSENTRY']._serialized_start=821
  _globals['_INSTRUMENT_DETECTORSENTRY']._serialized_end=902
  _globals['_INSTRUMENT_OBJECTIVESENTRY']._serialized_start=904
  _globals['_INSTRUMENT_OBJECTIVESENTRY']._serialized_end=987
  _globals['_INSTRUMENT_FILTERSETSENTRY']._serialized_start=989
  _globals['_INSTRUMENT_FILTERSETSENTRY']._serialized_end=1072
  _globals['_INSTRUMENT_FILTERSENTRY']._serialized_start=1074
  _globals['_INSTRUMENT_FILTERSENTRY']._serialized_end=1151
  _globals['_INSTRUMENT_DICHROICSENTRY']._serialized_start=1153
  _globals['_INSTRUMENT_DICHROICSENTRY']._serialized_end=1234
# @@protoc_insertion_point(module_scope)
