# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/detector_setting.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/detector_setting.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n biopb/ome/detector_setting.proto\x12\tbiopb.ome\"\xb3\x03\n\x0f\x44\x65tectorSetting\x12\x1f\n\x0b\x64\x65tector_id\x18\x01 \x01(\tR\ndetectorId\x12\x1b\n\x06offset\x18\x02 \x01(\x02H\x00R\x06offset\x88\x01\x01\x12\x17\n\x04gain\x18\x03 \x01(\x02H\x01R\x04gain\x88\x01\x01\x12\x1d\n\x07voltage\x18\x04 \x01(\x02H\x02R\x07voltage\x88\x01\x01\x12!\n\x0cvoltage_unit\x18\x05 \x01(\tR\x0bvoltageUnit\x12\x17\n\x04zoom\x18\x06 \x01(\x02H\x03R\x04zoom\x88\x01\x01\x12&\n\x0creadout_rate\x18\x07 \x01(\x02H\x04R\x0breadoutRate\x88\x01\x01\x12*\n\x11readout_rate_unit\x18\x08 \x01(\tR\x0freadoutRateUnit\x12\x1d\n\x07\x62inning\x18\t \x01(\rH\x05R\x07\x62inning\x88\x01\x01\x12%\n\x0bintegration\x18\n \x01(\rH\x06R\x0bintegration\x88\x01\x01\x42\t\n\x07_offsetB\x07\n\x05_gainB\n\n\x08_voltageB\x07\n\x05_zoomB\x0f\n\r_readout_rateB\n\n\x08_binningB\x0e\n\x0c_integrationB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.detector_setting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_DETECTORSETTING']._serialized_start=48
  _globals['_DETECTORSETTING']._serialized_end=483
# @@protoc_insertion_point(module_scope)
