# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/objective.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/objective.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x62iopb/ome/objective.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\xb2\x06\n\tObjective\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12?\n\ncorrection\x18\x03 \x01(\x0e\x32\x1f.biopb.ome.Objective.CorrectionR\ncorrection\x12\x1c\n\temmersion\x18\x04 \x01(\tR\temmersion\x12\x1c\n\x07lens_na\x18\x05 \x01(\x02H\x00R\x06lensNa\x88\x01\x01\x12\x38\n\x15nominal_magnification\x18\x06 \x01(\x02H\x01R\x14nominalMagnification\x88\x01\x01\x12>\n\x18\x63\x61librated_magnification\x18\x07 \x01(\x02H\x02R\x17\x63\x61libratedMagnification\x88\x01\x01\x12.\n\x10working_distance\x18\x08 \x01(\x02H\x03R\x0fworkingDistance\x88\x01\x01\x12\x32\n\x15working_distance_unit\x18\t \x01(\tR\x13workingDistanceUnit\x12\x17\n\x04iris\x18\n \x01(\x08H\x04R\x04iris\x88\x01\x01\x12%\n\x0e\x61nnotation_ids\x18\x0b \x03(\tR\rannotationIds\"\xde\x01\n\nCorrection\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02UV\x10\x01\x12\x0b\n\x07PLANAPO\x10\x02\x12\r\n\tPLANFLUOR\x10\x03\x12\x0e\n\nSUPERFLUOR\x10\x04\x12\x13\n\x0fVIOLETCORRECTED\x10\x05\x12\t\n\x05\x41\x43HRO\x10\x06\x12\x0c\n\x08\x41\x43HROMAT\x10\x07\x12\t\n\x05\x46LUOR\x10\x08\x12\x06\n\x02\x46L\x10\t\x12\t\n\x05\x46LUAR\x10\n\x12\x0c\n\x08\x45NOFLUAR\x10\x0b\x12\x0b\n\x07\x46LUOTAR\x10\x0c\x12\x07\n\x03\x41PO\x10\r\x12\x10\n\x0cPLANNEOFLUAR\x10\x0e\x12\t\n\x05OTHER\x10\x0f\x42\n\n\x08_lens_naB\x18\n\x16_nominal_magnificationB\x1b\n\x19_calibrated_magnificationB\x13\n\x11_working_distanceB\x07\n\x05_irisB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.objective_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_OBJECTIVE']._serialized_start=76
  _globals['_OBJECTIVE']._serialized_end=894
  _globals['_OBJECTIVE_CORRECTION']._serialized_start=575
  _globals['_OBJECTIVE_CORRECTION']._serialized_end=797
# @@protoc_insertion_point(module_scope)
