# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/microbeam_manipulation.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/microbeam_manipulation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import light_source_setting_pb2 as biopb_dot_ome_dot_light__source__setting__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&biopb/ome/microbeam_manipulation.proto\x12\tbiopb.ome\x1a$biopb/ome/light_source_setting.proto\"\xff\x01\n\x15MicrobeamManipulation\x12/\n\x04type\x18\x02 \x01(\x0e\x32\x1b.biopb.ome.ManipulationTypeR\x04type\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x17\n\x07roi_ids\x18\x04 \x03(\tR\x06roiIds\x12Q\n\x15light_source_settings\x18\x05 \x03(\x0b\x32\x1d.biopb.ome.LightSourceSettingR\x13lightSourceSettings\x12\'\n\x0f\x65xperimenter_id\x18\x06 \x01(\tR\x0e\x65xperimenterId*\x89\x01\n\x10ManipulationType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x46RAP\x10\x01\x12\x08\n\x04\x46LIP\x10\x02\x12\x0f\n\x0bINVERSEFRAP\x10\x03\x12\x11\n\rPHOTOABLATION\x10\x04\x12\x0c\n\x08UNCAGING\x10\x05\x12\x13\n\x0fOPTICALTRAPPING\x10\x06\x12\t\n\x05OTHER\x10\x07\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.microbeam_manipulation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_MANIPULATIONTYPE']._serialized_start=350
  _globals['_MANIPULATIONTYPE']._serialized_end=487
  _globals['_MICROBEAMMANIPULATION']._serialized_start=92
  _globals['_MICROBEAMMANIPULATION']._serialized_end=347
# @@protoc_insertion_point(module_scope)
