# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/microscope.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/microscope.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/microscope.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\xec\x01\n\nMicroscope\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12.\n\x04type\x18\x03 \x01(\x0e\x32\x1a.biopb.ome.Microscope.TypeR\x04type\"d\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UPRIGHT\x10\x01\x12\x0c\n\x08INVERTED\x10\x02\x12\x0e\n\nDISSECTION\x10\x03\x12\x15\n\x11\x45LECTROPHYSIOLOGY\x10\x04\x12\t\n\x05OTHER\x10\x05\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.microscope_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_MICROSCOPE']._serialized_start=77
  _globals['_MICROSCOPE']._serialized_end=313
  _globals['_MICROSCOPE_TYPE']._serialized_start=213
  _globals['_MICROSCOPE_TYPE']._serialized_end=313
# @@protoc_insertion_point(module_scope)
