# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/filter.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x62iopb/ome/filter.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\xd7\x03\n\x12TransmittanceRange\x12\x1a\n\x06\x63ut_in\x18\x02 \x01(\x02H\x00R\x05\x63utIn\x88\x01\x01\x12\x1e\n\x0b\x63ut_in_unit\x18\x03 \x01(\tR\tcutInUnit\x12\x1c\n\x07\x63ut_out\x18\x04 \x01(\x02H\x01R\x06\x63utOut\x88\x01\x01\x12 \n\x0c\x63ut_out_unit\x18\x05 \x01(\tR\ncutOutUnit\x12-\n\x10\x63ut_in_tolerance\x18\x06 \x01(\x02H\x02R\x0e\x63utInTolerance\x88\x01\x01\x12\x31\n\x15\x63ut_in_tolerance_unit\x18\x07 \x01(\tR\x12\x63utInToleranceUnit\x12/\n\x11\x63ut_out_tolerance\x18\x08 \x01(\x02H\x03R\x0f\x63utOutTolerance\x88\x01\x01\x12\x33\n\x16\x63ut_out_tolerance_unit\x18\t \x01(\tR\x13\x63utOutToleranceUnit\x12)\n\rtransmittance\x18\n \x01(\x02H\x04R\rtransmittance\x88\x01\x01\x42\t\n\x07_cut_inB\n\n\x08_cut_outB\x13\n\x11_cut_in_toleranceB\x14\n\x12_cut_out_toleranceB\x10\n\x0e_transmittance\"\xa6\x03\n\x06\x46ilter\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12*\n\x04type\x18\x03 \x01(\x0e\x32\x16.biopb.ome.Filter.TypeR\x04type\x12N\n\x13transmittence_range\x18\x04 \x01(\x0b\x32\x1d.biopb.ome.TransmittanceRangeR\x12transmittenceRange\x12!\n\x0c\x66ilter_wheel\x18\x05 \x01(\tR\x0b\x66ilterWheel\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIds\"\x8b\x01\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ICHROIC\x10\x01\x12\x0c\n\x08LONGPASS\x10\x02\x12\r\n\tSHORTPASS\x10\x03\x12\x0c\n\x08\x42\x41NDPASS\x10\x04\x12\r\n\tMULTIPASS\x10\x05\x12\x12\n\x0eNEUTRALDENSITY\x10\x06\x12\x0b\n\x07TUNABLE\x10\x07\x12\t\n\x05OTHER\x10\x08\"{\n\x08\x44ichroic\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIdsB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_TRANSMITTANCERANGE']._serialized_start=73
  _globals['_TRANSMITTANCERANGE']._serialized_end=544
  _globals['_FILTER']._serialized_start=547
  _globals['_FILTER']._serialized_end=969
  _globals['_FILTER_TYPE']._serialized_start=830
  _globals['_FILTER_TYPE']._serialized_end=969
  _globals['_DICHROIC']._serialized_start=971
  _globals['_DICHROIC']._serialized_end=1094
# @@protoc_insertion_point(module_scope)
