# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/experiment.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/experiment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import microbeam_manipulation_pb2 as biopb_dot_ome_dot_microbeam__manipulation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x62iopb/ome/experiment.proto\x12\tbiopb.ome\x1a&biopb/ome/microbeam_manipulation.proto\"\xae\x05\n\nExperiment\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32$.biopb.ome.Experiment.ExperimentTypeR\x04type\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12j\n\x17microbeam_manipulations\x18\x04 \x03(\x0b\x32\x31.biopb.ome.Experiment.MicrobeamManipulationsEntryR\x16microbeamManipulations\x12\'\n\x0f\x65xperimenter_id\x18\x05 \x01(\tR\x0e\x65xperimenterId\x1ak\n\x1bMicrobeamManipulationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32 .biopb.ome.MicrobeamManipulationR\x05value:\x02\x38\x01\"\xc1\x02\n\x0e\x45xperimentType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02\x46P\x10\x01\x12\x08\n\x04\x46RET\x10\x02\x12\r\n\tTIMELAPSE\x10\x03\x12\r\n\tFOURDPLUS\x10\x04\x12\n\n\x06SCREEN\x10\x05\x12\x17\n\x13IMMUNOCYTOCHEMISTRY\x10\x06\x12\x16\n\x12IMMUNOFLUORESCENCE\x10\x07\x12\x08\n\x04\x46ISH\x10\x08\x12\x15\n\x11\x45LECTROPHYSIOLOGY\x10\t\x12\x0e\n\nIONIMAGING\x10\n\x12\x12\n\x0e\x43OLOCALIZATION\x10\x0b\x12\x14\n\x10PGIDOCUMENTATION\x10\x0c\x12\x18\n\x14\x46LUORESCENCELIFETIME\x10\r\x12\x13\n\x0fSPECTRALIMAGING\x10\x0e\x12\x12\n\x0ePHOTOBLEACHING\x10\x0f\x12\x08\n\x04SPIM\x10\x10\x12\t\n\x05OTHER\x10\x11\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.experiment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_EXPERIMENT_MICROBEAMMANIPULATIONSENTRY']._loaded_options = None
  _globals['_EXPERIMENT_MICROBEAMMANIPULATIONSENTRY']._serialized_options = b'8\001'
  _globals['_EXPERIMENT']._serialized_start=82
  _globals['_EXPERIMENT']._serialized_end=768
  _globals['_EXPERIMENT_MICROBEAMMANIPULATIONSENTRY']._serialized_start=337
  _globals['_EXPERIMENT_MICROBEAMMANIPULATIONSENTRY']._serialized_end=444
  _globals['_EXPERIMENT_EXPERIMENTTYPE']._serialized_start=447
  _globals['_EXPERIMENT_EXPERIMENTTYPE']._serialized_end=768
# @@protoc_insertion_point(module_scope)
