# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/light_source.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/light_source.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x62iopb/ome/light_source.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\x83\x05\n\x05Laser\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x15.biopb.ome.Laser.TypeR\x04type\x12!\n\x0claser_medium\x18\x03 \x01(\tR\x0blaserMedium\x12#\n\nWavelength\x18\x04 \x01(\x02H\x00R\nWavelength\x88\x01\x01\x12\'\n\x0fwavelength_unit\x18\x05 \x01(\tR\x0ewavelengthUnit\x12<\n\x17\x66\x65quency_multiplication\x18\x06 \x01(\x05H\x01R\x16\x66\x65quencyMultiplication\x88\x01\x01\x12\x1d\n\x07tunable\x18\x07 \x01(\x08H\x02R\x07tunable\x88\x01\x01\x12\x14\n\x05pulse\x18\x08 \x01(\tR\x05pulse\x12$\n\x0bpockel_cell\x18\t \x01(\x08H\x03R\npockelCell\x88\x01\x01\x12,\n\x0frepetition_rate\x18\n \x01(\rH\x04R\x0erepetitionRate\x88\x01\x01\x12\x30\n\x14repetition_rate_unit\x18\x0b \x01(\tR\x12repetitionRateUnit\"\x89\x01\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XCIMER\x10\x01\x12\x07\n\x03GAS\x10\x02\x12\x0f\n\x0bMETAL_VAPOR\x10\x03\x12\x0f\n\x0bSOLID_STATE\x10\x04\x12\x07\n\x03\x44YE\x10\x05\x12\x11\n\rSEMICONDUCTOR\x10\x06\x12\x11\n\rFREE_ELECTRON\x10\x07\x12\t\n\x05OTHER\x10\x08\x42\r\n\x0b_WavelengthB\x1a\n\x18_fequency_multiplicationB\n\n\x08_tunableB\x0e\n\x0c_pockel_cellB\x12\n\x10_repetition_rate\"m\n\x03\x41rc\x12\'\n\x04type\x18\x02 \x01(\x0e\x32\x13.biopb.ome.Arc.TypeR\x04type\"=\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02HG\x10\x01\x12\x06\n\x02XE\x10\x02\x12\t\n\x05HG_XE\x10\x03\x12\t\n\x05OTHER\x10\x04\"{\n\x08\x46ilament\x12,\n\x04type\x18\x02 \x01(\x0e\x32\x18.biopb.ome.Filament.TypeR\x04type\"A\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x10\n\x0cINCANDESCENT\x10\x01\x12\x0b\n\x07HALOGEN\x10\x02\x12\t\n\x05OTHER\x10\x03\"\x14\n\x12LightEmittingDiode\"\xac\x01\n\x17GenericExcitationSource\x12R\n\nattributes\x18\x02 \x03(\x0b\x32\x32.biopb.ome.GenericExcitationSource.AttributesEntryR\nattributes\x1a=\n\x0f\x41ttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8a\x04\n\x0bLightSource\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12\x19\n\x05power\x18\x03 \x01(\x02H\x01R\x05power\x88\x01\x01\x12\x1f\n\x0bpower_units\x18\x04 \x01(\tR\npowerUnits\x12%\n\x0e\x61nnotation_ids\x18\x05 \x01(\tR\rannotationIds\x12(\n\x05laser\x18\x06 \x01(\x0b\x32\x10.biopb.ome.LaserH\x00R\x05laser\x12\"\n\x03\x61rc\x18\x07 \x01(\x0b\x32\x0e.biopb.ome.ArcH\x00R\x03\x61rc\x12\x31\n\x08\x66ilament\x18\x08 \x01(\x0b\x32\x13.biopb.ome.FilamentH\x00R\x08\x66ilament\x12Q\n\x14light_emitting_diode\x18\t \x01(\x0b\x32\x1d.biopb.ome.LightEmittingDiodeH\x00R\x12lightEmittingDiode\x12`\n\x19generic_excitation_source\x18\n \x01(\x0b\x32\".biopb.ome.GenericExcitationSourceH\x00R\x17genericExcitationSourceB\x0e\n\x0clight_sourceB\x08\n\x06_powerB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.light_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_GENERICEXCITATIONSOURCE_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_GENERICEXCITATIONSOURCE_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_LASER']._serialized_start=79
  _globals['_LASER']._serialized_end=722
  _globals['_LASER_TYPE']._serialized_start=494
  _globals['_LASER_TYPE']._serialized_end=631
  _globals['_ARC']._serialized_start=724
  _globals['_ARC']._serialized_end=833
  _globals['_ARC_TYPE']._serialized_start=772
  _globals['_ARC_TYPE']._serialized_end=833
  _globals['_FILAMENT']._serialized_start=835
  _globals['_FILAMENT']._serialized_end=958
  _globals['_FILAMENT_TYPE']._serialized_start=893
  _globals['_FILAMENT_TYPE']._serialized_end=958
  _globals['_LIGHTEMITTINGDIODE']._serialized_start=960
  _globals['_LIGHTEMITTINGDIODE']._serialized_end=980
  _globals['_GENERICEXCITATIONSOURCE']._serialized_start=983
  _globals['_GENERICEXCITATIONSOURCE']._serialized_end=1155
  _globals['_GENERICEXCITATIONSOURCE_ATTRIBUTESENTRY']._serialized_start=1094
  _globals['_GENERICEXCITATIONSOURCE_ATTRIBUTESENTRY']._serialized_end=1155
  _globals['_LIGHTSOURCE']._serialized_start=1158
  _globals['_LIGHTSOURCE']._serialized_end=1680
# @@protoc_insertion_point(module_scope)
