# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/detector.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/detector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import manufacturer_spec_pb2 as biopb_dot_ome_dot_manufacturer__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62iopb/ome/detector.proto\x12\tbiopb.ome\x1a!biopb/ome/manufacturer_spec.proto\"\x95\x05\n\x08\x44\x65tector\x12H\n\x11manufacturer_spec\x18\x02 \x01(\x0b\x32\x1b.biopb.ome.ManufacturerSpecR\x10manufacturerSpec\x12,\n\x04type\x18\x03 \x01(\x0e\x32\x18.biopb.ome.Detector.TypeR\x04type\x12\x17\n\x04gain\x18\x04 \x01(\x02H\x00R\x04gain\x88\x01\x01\x12\x1d\n\x07voltage\x18\x05 \x01(\x02H\x01R\x07voltage\x88\x01\x01\x12!\n\x0cvoltage_unit\x18\x06 \x01(\tR\x0bvoltageUnit\x12\x1b\n\x06offset\x18\x07 \x01(\x02H\x02R\x06offset\x88\x01\x01\x12\x17\n\x04zoom\x18\x08 \x01(\x02H\x03R\x04zoom\x88\x01\x01\x12\x32\n\x12\x61mplification_gain\x18\t \x01(\x02H\x04R\x11\x61mplificationGain\x88\x01\x01\x12%\n\x0e\x61nnotation_ids\x18\n \x03(\tR\rannotationIds\"\xe4\x01\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x07\n\x03\x43\x43\x44\x10\x01\x12\x13\n\x0fINTENSIFIED_CCD\x10\x02\x12\x10\n\x0c\x41NALOG_VIDEO\x10\x03\x12\x07\n\x03PMT\x10\x04\x12\x0e\n\nPHOTODIODE\x10\x05\x12\x10\n\x0cSPECTROSCOPY\x10\x06\x12\x14\n\x10LIFETIME_IMAGING\x10\x07\x12\x1c\n\x18\x43ORRELATION_SPECTROSCOPY\x10\x08\x12\x08\n\x04\x46TIR\x10\t\x12\t\n\x05\x45MCCD\x10\n\x12\x07\n\x03\x41PD\x10\x0b\x12\x08\n\x04\x43MOD\x10\x0c\x12\t\n\x05\x45\x42\x43\x43\x44\x10\r\x12\t\n\x05OTHER\x10\x0e\x42\x07\n\x05_gainB\n\n\x08_voltageB\t\n\x07_offsetB\x07\n\x05_zoomB\x15\n\x13_amplification_gainB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.detector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_DETECTOR']._serialized_start=75
  _globals['_DETECTOR']._serialized_end=736
  _globals['_DETECTOR_TYPE']._serialized_start=444
  _globals['_DETECTOR_TYPE']._serialized_end=672
# @@protoc_insertion_point(module_scope)
