# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/screen.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/screen.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import reagent_pb2 as biopb_dot_ome_dot_reagent__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x62iopb/ome/screen.proto\x12\tbiopb.ome\x1a\x17\x62iopb/ome/reagent.proto\"\xa6\x03\n\x06Screen\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12;\n\x08reagents\x18\x03 \x03(\x0b\x32\x1f.biopb.ome.Screen.ReagentsEntryR\x08reagents\x12\x1b\n\tplate_ids\x18\x04 \x03(\tR\x08plateIds\x12/\n\x13protocol_identifier\x18\x05 \x01(\tR\x12protocolIdentifier\x12\x31\n\x14protocol_description\x18\x06 \x01(\tR\x13protocolDescription\x12/\n\x13reagent_description\x18\x07 \x01(\tR\x12reagentDescription\x12\x34\n\x16reagent_set_identifier\x18\x08 \x01(\tR\x14reagentSetIdentifier\x12\x12\n\x04type\x18\t \x01(\tR\x04type\x1aO\n\rReagentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x12.biopb.ome.ReagentR\x05value:\x02\x38\x01\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.screen_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_SCREEN_REAGENTSENTRY']._loaded_options = None
  _globals['_SCREEN_REAGENTSENTRY']._serialized_options = b'8\001'
  _globals['_SCREEN']._serialized_start=63
  _globals['_SCREEN']._serialized_end=485
  _globals['_SCREEN_REAGENTSENTRY']._serialized_start=406
  _globals['_SCREEN_REAGENTSENTRY']._serialized_end=485
# @@protoc_insertion_point(module_scope)
