# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/image/rpc_object_detection.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/image/rpc_object_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from biopb.image import detection_request_pb2 as biopb_dot_image_dot_detection__request__pb2
from biopb.image import detection_response_pb2 as biopb_dot_image_dot_detection__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&biopb/image/rpc_object_detection.proto\x12\x0b\x62iopb.image\x1a\x19google/protobuf/any.proto\x1a#biopb/image/detection_request.proto\x1a$biopb/image/detection_response.proto2\xdd\x02\n\x0fObjectDetection\x12M\n\x0cRunDetection\x12\x1d.biopb.image.DetectionRequest\x1a\x1e.biopb.image.DetectionResponse\x12W\n\x12RunDetectionStream\x12\x1d.biopb.image.DetectionRequest\x1a\x1e.biopb.image.DetectionResponse(\x01\x30\x01\x12U\n\x12RunDetectionOnGrid\x12\x1d.biopb.image.DetectionRequest\x1a\x1e.biopb.image.DetectionResponse(\x01\x12K\n\x12RunModelAdaptation\x12\x1d.biopb.image.DetectionRequest\x1a\x14.google.protobuf.Any(\x01\x42\x0f\n\x0b\x62iopb.imageP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.image.rpc_object_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013biopb.imageP\001'
  _globals['_OBJECTDETECTION']._serialized_start=158
  _globals['_OBJECTDETECTION']._serialized_end=507
# @@protoc_insertion_point(module_scope)
