# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/image/rpc_process_image.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/image/rpc_process_image.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from biopb.image import image_data_pb2 as biopb_dot_image_dot_image__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#biopb/image/rpc_process_image.proto\x12\x0b\x62iopb.image\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1c\x62iopb/image/image_data.proto\"\x9b\x01\n\x0eProcessRequest\x12\x35\n\nimage_data\x18\x01 \x01(\x0b\x32\x16.biopb.image.ImageDataR\timageData\x12\x17\n\x07op_name\x18\x02 \x01(\tR\x06opName\x12\x39\n\nfield_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"h\n\x0fProcessResponse\x12\x35\n\nimage_data\x18\x01 \x01(\x0b\x32\x16.biopb.image.ImageDataR\timageData\x12\x1e\n\nannotation\x18\x02 \x01(\tR\nannotation\"\x1f\n\x07OpNames\x12\x14\n\x05names\x18\x01 \x03(\tR\x05names2\xd8\x01\n\x0cProcessImage\x12@\n\x03Run\x12\x1b.biopb.image.ProcessRequest\x1a\x1c.biopb.image.ProcessResponse\x12J\n\tRunStream\x12\x1b.biopb.image.ProcessRequest\x1a\x1c.biopb.image.ProcessResponse(\x01\x30\x01\x12:\n\nGetOpNames\x12\x16.google.protobuf.Empty\x1a\x14.biopb.image.OpNamesB\x0f\n\x0b\x62iopb.imageP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.image.rpc_process_image_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013biopb.imageP\001'
  _globals['_PROCESSREQUEST']._serialized_start=146
  _globals['_PROCESSREQUEST']._serialized_end=301
  _globals['_PROCESSRESPONSE']._serialized_start=303
  _globals['_PROCESSRESPONSE']._serialized_end=407
  _globals['_OPNAMES']._serialized_start=409
  _globals['_OPNAMES']._serialized_end=440
  _globals['_PROCESSIMAGE']._serialized_start=443
  _globals['_PROCESSIMAGE']._serialized_end=659
# @@protoc_insertion_point(module_scope)
