# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/ome.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/ome.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import rights_pb2 as biopb_dot_ome_dot_rights__pb2
from biopb.ome import metadata_pb2 as biopb_dot_ome_dot_metadata__pb2
from biopb.ome import metadata_ref_pb2 as biopb_dot_ome_dot_metadata__ref__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x62iopb/ome/ome.proto\x12\tbiopb.ome\x1a\x16\x62iopb/ome/rights.proto\x1a\x18\x62iopb/ome/metadata.proto\x1a\x1c\x62iopb/ome/metadata_ref.proto\"\xca\x01\n\x03OME\x12)\n\x06rights\x18\x01 \x01(\x0b\x32\x11.biopb.ome.RightsR\x06rights\x12/\n\x08metadata\x18\x02 \x01(\x0b\x32\x13.biopb.ome.MetadataR\x08metadata\x12\x39\n\x0cmetadata_ref\x18\x03 \x01(\x0b\x32\x16.biopb.ome.MetadataRefR\x0bmetadataRef\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\x18\n\x07\x63reator\x18\x05 \x01(\tR\x07\x63reatorB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.ome_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_OME']._serialized_start=115
  _globals['_OME']._serialized_end=317
# @@protoc_insertion_point(module_scope)
