# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/pixel.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/pixel.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biopb.ome import bindata_pb2 as biopb_dot_ome_dot_bindata__pb2
from biopb.ome import light_source_setting_pb2 as biopb_dot_ome_dot_light__source__setting__pb2
from biopb.ome import detector_setting_pb2 as biopb_dot_ome_dot_detector__setting__pb2
from biopb.ome import lightpath_pb2 as biopb_dot_ome_dot_lightpath__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62iopb/ome/pixel.proto\x12\tbiopb.ome\x1a\x17\x62iopb/ome/bindata.proto\x1a$biopb/ome/light_source_setting.proto\x1a biopb/ome/detector_setting.proto\x1a\x19\x62iopb/ome/lightpath.proto\"\xa0\x04\n\x05Plane\x12\x1b\n\thash_sha1\x18\x01 \x01(\x0cR\x08hashSha1\x12\x18\n\x05the_z\x18\x02 \x01(\rH\x00R\x04theZ\x88\x01\x01\x12\x18\n\x05the_t\x18\x03 \x01(\rH\x01R\x04theT\x88\x01\x01\x12\x18\n\x05the_c\x18\x04 \x01(\rH\x02R\x04theC\x88\x01\x01\x12\x1c\n\x07\x64\x65lta_t\x18\x05 \x01(\x02H\x03R\x06\x64\x65ltaT\x88\x01\x01\x12\x1e\n\x0b\x64\x65lt_t_unit\x18\x06 \x01(\tR\tdeltTUnit\x12(\n\rexposure_time\x18\x07 \x01(\x02H\x04R\x0c\x65xposureTime\x88\x01\x01\x12,\n\x12\x65xposure_time_unit\x18\x08 \x01(\tR\x10\x65xposureTimeUnit\x12 \n\tpostion_x\x18\t \x01(\x02H\x05R\x08postionX\x88\x01\x01\x12 \n\tpostion_y\x18\n \x01(\x02H\x06R\x08postionY\x88\x01\x01\x12 \n\tpostion_z\x18\x0b \x01(\x02H\x07R\x08postionZ\x88\x01\x01\x12#\n\rposition_unit\x18\x0c \x01(\tR\x0cpositionUnit\x12%\n\x0e\x61nnotation_ids\x18\x0f \x03(\tR\rannotationIdsB\x08\n\x06_the_zB\x08\n\x06_the_tB\x08\n\x06_the_cB\n\n\x08_delta_tB\x10\n\x0e_exposure_timeB\x0c\n\n_postion_xB\x0c\n\n_postion_yB\x0c\n\n_postion_z\"\xb3\x08\n\x07\x43hannel\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12O\n\x14light_source_setting\x18\x03 \x01(\x0b\x32\x1d.biopb.ome.LightSourceSettingR\x12lightSourceSetting\x12\x45\n\x10\x64\x65tector_setting\x18\x04 \x01(\x0b\x32\x1a.biopb.ome.DetectorSettingR\x0f\x64\x65tectorSetting\x12!\n\x0c\x46ilterSet_id\x18\x05 \x01(\tR\x0b\x46ilterSetId\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIds\x12\x33\n\nlight_path\x18\x07 \x01(\x0b\x32\x14.biopb.ome.LightPathR\tlightPath\x12/\n\x11samples_per_pixel\x18\x08 \x01(\rH\x00R\x0fsamplesPerPixel\x88\x01\x01\x12+\n\x11illumination_type\x18\t \x01(\tR\x10illuminationType\x12&\n\x0cpinhole_size\x18\n \x01(\x02H\x01R\x0bpinholeSize\x88\x01\x01\x12*\n\x11pinhole_size_unit\x18\x0b \x01(\tR\x0fpinholeSizeUnit\x12+\n\x11\x61\x63quisition_model\x18\x0c \x01(\tR\x10\x61\x63quisitionModel\x12\'\n\x0f\x63ontrast_method\x18\r \x01(\tR\x0e\x63ontrastMethod\x12\x38\n\x15\x65xcitation_wavelength\x18\x0e \x01(\x02H\x02R\x14\x65xcitationWavelength\x88\x01\x01\x12:\n\x19\x65xitation_wavelength_unit\x18\x0f \x01(\tR\x17\x65xitationWavelengthUnit\x12\x34\n\x13\x65mission_wavelength\x18\x10 \x01(\x02H\x03R\x12\x65missionWavelength\x88\x01\x01\x12\x38\n\x18\x65mission_wavelength_unit\x18\x11 \x01(\tR\x16\x65missionWavelengthUnit\x12\x14\n\x05\x66luor\x18\x12 \x01(\tR\x05\x66luor\x12 \n\tnd_filter\x18\x13 \x01(\x02H\x04R\x08ndFilter\x88\x01\x01\x12\x33\n\x13pockle_cell_setting\x18\x14 \x01(\x05H\x05R\x11pockleCellSetting\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x15 \x01(\rH\x06R\x05\x63olor\x88\x01\x01\x42\x14\n\x12_samples_per_pixelB\x0f\n\r_pinhole_sizeB\x18\n\x16_excitation_wavelengthB\x16\n\x14_emission_wavelengthB\x0c\n\n_nd_filterB\x16\n\x14_pockle_cell_settingB\x08\n\x06_color\"\xbe\x08\n\x06Pixels\x12.\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x12.biopb.ome.ChannelR\x08\x63hannels\x12(\n\x06planes\x18\x02 \x03(\x0b\x32\x10.biopb.ome.PlaneR\x06planes\x12,\n\x07\x62indata\x18\x03 \x03(\x0b\x32\x12.biopb.ome.BinDataR\x07\x62indata\x12\'\n\x0f\x64imension_order\x18\x04 \x01(\tR\x0e\x64imensionOrder\x12:\n\npixel_type\x18\x05 \x01(\x0e\x32\x1b.biopb.ome.Pixels.PixelTypeR\tpixelType\x12.\n\x10significant_bits\x18\x06 \x01(\rH\x00R\x0fsignificantBits\x88\x01\x01\x12%\n\x0binterleaved\x18\x07 \x01(\x08H\x01R\x0binterleaved\x88\x01\x01\x12\"\n\nbig_endian\x18\x08 \x01(\x08H\x02R\tbigEndian\x88\x01\x01\x12\x15\n\x06size_x\x18\t \x01(\rR\x05sizeX\x12\x15\n\x06size_y\x18\n \x01(\rR\x05sizeY\x12\x15\n\x06size_z\x18\x0b \x01(\rR\x05sizeZ\x12\x15\n\x06size_c\x18\x0c \x01(\rR\x05sizeC\x12\x15\n\x06size_t\x18\r \x01(\rR\x05sizeT\x12+\n\x0fphysical_size_x\x18\x0e \x01(\x02H\x03R\rphysicalSizeX\x88\x01\x01\x12+\n\x0fphysical_size_y\x18\x0f \x01(\x02H\x04R\rphysicalSizeY\x88\x01\x01\x12+\n\x0fphysical_size_z\x18\x10 \x01(\x02H\x05R\rphysicalSizeZ\x88\x01\x01\x12,\n\x12physical_size_unit\x18\x11 \x01(\tR\x10physicalSizeUnit\x12*\n\x0etime_increment\x18\x12 \x01(\x02H\x06R\rtimeIncrement\x88\x01\x01\x12.\n\x13time_increment_unit\x18\x15 \x01(\tR\x11timeIncrementUnit\"\xc4\x01\n\tPixelType\x12\x12\n\x0ePT_UNSPECIFIED\x10\x00\x12\x0b\n\x07PT_INT8\x10\x01\x12\x0c\n\x08PT_INT16\x10\x02\x12\x0c\n\x08PT_INT32\x10\x03\x12\x0c\n\x08PT_UINT8\x10\x04\x12\r\n\tPT_UINT16\x10\x05\x12\r\n\tPT_UINT32\x10\x06\x12\x0c\n\x08PT_FLOAT\x10\x07\x12\r\n\tPT_DOUBLE\x10\x08\x12\x0e\n\nPT_COMPLEX\x10\t\x12\x15\n\x11PT_DOUBLE_COMPLEX\x10\n\x12\n\n\x06PT_BIT\x10\x0b\x42\x13\n\x11_significant_bitsB\x0e\n\x0c_interleavedB\r\n\x0b_big_endianB\x12\n\x10_physical_size_xB\x12\n\x10_physical_size_yB\x12\n\x10_physical_size_zB\x11\n\x0f_time_incrementB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.pixel_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_PLANE']._serialized_start=161
  _globals['_PLANE']._serialized_end=705
  _globals['_CHANNEL']._serialized_start=708
  _globals['_CHANNEL']._serialized_end=1783
  _globals['_PIXELS']._serialized_start=1786
  _globals['_PIXELS']._serialized_end=2872
  _globals['_PIXELS_PIXELTYPE']._serialized_start=2545
  _globals['_PIXELS_PIXELTYPE']._serialized_end=2741
# @@protoc_insertion_point(module_scope)
