# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/image.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/image.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from biopb.ome import objective_setting_pb2 as biopb_dot_ome_dot_objective__setting__pb2
from biopb.ome import pixel_pb2 as biopb_dot_ome_dot_pixel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62iopb/ome/image.proto\x12\tbiopb.ome\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!biopb/ome/objective_setting.proto\x1a\x15\x62iopb/ome/pixel.proto\"\xbf\x02\n\x12ImagingEnvironment\x12%\n\x0btemperature\x18\x01 \x01(\x02H\x00R\x0btemperature\x88\x01\x01\x12)\n\x10temperature_unit\x18\x02 \x01(\tR\x0ftemperatureUnit\x12&\n\x0c\x61ir_pressure\x18\x03 \x01(\x02H\x01R\x0b\x61irPressure\x88\x01\x01\x12*\n\x11\x61ir_pressure_unit\x18\x04 \x01(\tR\x0f\x61irPressureUnit\x12\x1f\n\x08humidity\x18\x05 \x01(\x02H\x02R\x08humidity\x88\x01\x01\x12$\n\x0b\x63o2_percent\x18\x06 \x01(\x02H\x03R\nco2Percent\x88\x01\x01\x42\x0e\n\x0c_temperatureB\x0f\n\r_air_pressureB\x0b\n\t_humidityB\x0e\n\x0c_co2_percent\"\xb0\x01\n\nStageLabel\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x11\n\x01x\x18\x03 \x01(\x02H\x00R\x01x\x88\x01\x01\x12\x15\n\x06x_unit\x18\x04 \x01(\tR\x05xUnit\x12\x11\n\x01y\x18\x05 \x01(\x02H\x01R\x01y\x88\x01\x01\x12\x15\n\x06y_unit\x18\x06 \x01(\tR\x05yUnit\x12\x11\n\x01z\x18\x07 \x01(\x02H\x02R\x01z\x88\x01\x01\x12\x15\n\x06z_unit\x18\x08 \x01(\tR\x05zUnitB\x04\n\x02_xB\x04\n\x02_yB\x04\n\x02_z\"\xa2\x05\n\x05Image\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x45\n\x10\x61\x63quisition_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x61\x63quisitionDate\x12\'\n\x0f\x65xperimenter_id\x18\x05 \x01(\tR\x0e\x65xperimenterId\x12#\n\rexperiment_id\x18\x06 \x01(\tR\x0c\x65xperimentId\x12.\n\x13\x65xperiment_group_id\x18\x07 \x01(\tR\x11\x65xperimentGroupId\x12#\n\rinstrument_id\x18\x08 \x01(\tR\x0cinstrumentId\x12<\n\x1amicrobeam_manipulation_ids\x18\t \x03(\tR\x18microbeamManipulationIds\x12\x17\n\x07roi_ids\x18\n \x03(\tR\x06roiIds\x12%\n\x0e\x61nnotation_ids\x18\x0b \x03(\tR\rannotationIds\x12H\n\x11objective_setting\x18\x0c \x01(\x0b\x32\x1b.biopb.ome.ObjectiveSettingR\x10objectiveSetting\x12N\n\x13imaging_environment\x18\r \x01(\x0b\x32\x1d.biopb.ome.ImagingEnvironmentR\x12imagingEnvironment\x12\x36\n\x0bstage_label\x18\x0e \x01(\x0b\x32\x15.biopb.ome.StageLabelR\nstageLabel\x12)\n\x06pixels\x18\x0f \x01(\x0b\x32\x11.biopb.ome.PixelsR\x06pixelsB\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.image_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_IMAGINGENVIRONMENT']._serialized_start=128
  _globals['_IMAGINGENVIRONMENT']._serialized_end=447
  _globals['_STAGELABEL']._serialized_start=450
  _globals['_STAGELABEL']._serialized_end=626
  _globals['_IMAGE']._serialized_start=629
  _globals['_IMAGE']._serialized_end=1303
# @@protoc_insertion_point(module_scope)
