# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/image/detection_settings.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/image/detection_settings.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$biopb/image/detection_settings.proto\x12\x0b\x62iopb.image\x1a\x19google/protobuf/any.proto\"\xc9\x03\n\x11\x44\x65tectionSettings\x12\'\n\rmin_cell_area\x18\x01 \x01(\x02H\x01R\x0bminCellArea\x88\x01\x01\x12 \n\tmin_score\x18\x02 \x01(\x02H\x02R\x08minScore\x88\x01\x01\x12:\n\x16segmentation_threshold\x18\x03 \x01(\x02H\x03R\x15segmentationThreshold\x88\x01\x01\x12\x1c\n\x07nms_iou\x18\x04 \x01(\x02H\x04R\x06nmsIou\x88\x01\x01\x12.\n\x12\x63\x65ll_diameter_hint\x18\x06 \x01(\x02H\x00R\x10\x63\x65llDiameterHint\x12#\n\x0cscaling_hint\x18\x07 \x01(\x02H\x00R\x0bscalingHint\x12\x1d\n\nmodel_name\x18\x08 \x01(\tR\tmodelName\x12\x45\n\x13model_configuration\x18\t \x01(\x0b\x32\x14.google.protobuf.AnyR\x12modelConfigurationB\r\n\x0bresize_infoB\x10\n\x0e_min_cell_areaB\x0c\n\n_min_scoreB\x19\n\x17_segmentation_thresholdB\n\n\x08_nms_iouB\x0f\n\x0b\x62iopb.imageP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.image.detection_settings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013biopb.imageP\001'
  _globals['_DETECTIONSETTINGS']._serialized_start=81
  _globals['_DETECTIONSETTINGS']._serialized_end=538
# @@protoc_insertion_point(module_scope)
