# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: biopb/ome/folder.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'biopb/ome/folder.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x62iopb/ome/folder.proto\x12\tbiopb.ome\"\xb1\x02\n\x06\x46older\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x42\n\x0bsub_folders\x18\x04 \x03(\x0b\x32!.biopb.ome.Folder.SubFoldersEntryR\nsubFolders\x12\x1b\n\timage_ids\x18\x05 \x03(\tR\x08imageIds\x12%\n\x0e\x61nnotation_ids\x18\x06 \x03(\tR\rannotationIds\x12\x17\n\x07roi_ids\x18\x07 \x03(\tR\x06roiIds\x1aP\n\x0fSubFoldersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.biopb.ome.FolderR\x05value:\x02\x38\x01\x42\r\n\tbiopb.omeP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'biopb.ome.folder_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tbiopb.omeP\001'
  _globals['_FOLDER_SUBFOLDERSENTRY']._loaded_options = None
  _globals['_FOLDER_SUBFOLDERSENTRY']._serialized_options = b'8\001'
  _globals['_FOLDER']._serialized_start=38
  _globals['_FOLDER']._serialized_end=343
  _globals['_FOLDER_SUBFOLDERSENTRY']._serialized_start=263
  _globals['_FOLDER_SUBFOLDERSENTRY']._serialized_end=343
# @@protoc_insertion_point(module_scope)
